"""Constants for Pulp Maven plugin tests."""
from urllib.parse import urljoin

from pulp_smash.pulp3.constants import (
    BASE_CONTENT_PATH,
    BASE_DISTRIBUTION_PATH,
    BASE_PUBLISHER_PATH,
    BASE_REMOTE_PATH,
    BASE_REPO_PATH,
)

DOWNLOAD_POLICIES = ["on_demand"]

MAVEN_CONTENT_NAME = "maven.artifact"

MAVEN_CONTENT_PATH = urljoin(BASE_CONTENT_PATH, "maven/artifact/")

MAVEN_DISTRIBUTION_PATH = urljoin(BASE_DISTRIBUTION_PATH, "maven/maven/")

MAVEN_REMOTE_PATH = urljoin(BASE_REMOTE_PATH, "maven/maven/")

MAVEN_REPO_PATH = urljoin(BASE_REPO_PATH, "maven/maven/")

MAVEN_PUBLISHER_PATH = urljoin(BASE_PUBLISHER_PATH, "maven/maven/")

MAVEN_FIXTURE_URL = "https://repo1.maven.org/maven2/"



from pulpcore.plugin import viewsets as core

from . import models, serializers


class MavenArtifactFilter(core.ContentFilter):
    """
    FilterSet for MavenArtifact.
    """

    class Meta:
        model = models.MavenArtifact
        fields = ["group_id", "artifact_id", "version", "filename"]


class MavenArtifactViewSet(core.ContentViewSet):
    """
    A ViewSet for MavenArtifact.
    """

    endpoint_name = "artifact"
    queryset = models.MavenArtifact.objects.all()
    serializer_class = serializers.MavenArtifactSerializer
    filterset_class = MavenArtifactFilter


class MavenRemoteViewSet(core.RemoteViewSet):
    """
    A ViewSet for MavenRemote.
    """

    endpoint_name = "maven"
    queryset = models.MavenRemote.objects.all()
    serializer_class = serializers.MavenRemoteSerializer


class MavenRepositoryViewSet(core.RepositoryViewSet):
    """
    A ViewSet for MavenRemote.
    """

    endpoint_name = "maven"
    queryset = models.MavenRepository.objects.all()
    serializer_class = serializers.MavenRepositorySerializer


class MavenRepositoryVersionViewSet(core.RepositoryVersionViewSet):
    """
    MavenRepositoryVersion represents a single Maven repository version.
    """

    parent_viewset = MavenRepositoryViewSet


class MavenDistributionViewSet(core.DistributionViewSet):
    """
    ViewSet for Maven Distributions.
    """

    endpoint_name = "maven"
    queryset = models.MavenDistribution.objects.all()
    serializer_class = serializers.MavenDistributionSerializer
